==> nextcloud-26.0.9.tgz: nextcloud/apps/logreader/l10n/ja.js <==
OC.L10N.register(
    "logreader",
    {
    "Logging" : "ログ",
    "Log Reader" : "ログリーダー",
    "A log reader for Nextcloud" : "NextCloudのためのログリーダー",
    "Log reader for Nextcloud" : "NextCloudのためのログリーダー",
    "Log reader" : "ログリーダー",
    "Open log reader settings" : "ログリーダーの設定を開く",
    "Log reader settings" : "ログリーダーの設定",
    "Currently the log file {file} is shown" : "現在、ログファイル {file} が表示されています。",
    "Show server log" : "サーバーログを表示",
    "Live view is disabled" : "ライブビューは無効",
    "No log file" : "ログファイルがありません",
    "File-based logging must be enabled to access logs from the Web UI." : "Web UIからログにアクセスするには、ファイルベースのログを有効にする必要があります。",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "エラーと思われる場合は、 {config} の {setting} を確認し、Nextcloud管理マニュアルをご確認ください。",
    "Level" : "レベル",
    "App" : "アプリ",
    "No app in context" : "No app in context",
    "Time" : "時間",
    "Copy raw entry" : "原文のままコピーする",
    "Copy formatted entry" : "フォーマットされたエントリーをコピーする",
    "Hide exception details" : "例外の詳細を非表示にする",
    "View exception details" : "例外の詳細を表示する",
    "Raw log entry" : "原文のログエントリー",
    "Log entry successfully copied" : "ログが正常にコピーされました",
    "Search log entries" : "ログの検索",
    "Caused by {exception}" : "{exception} が原因",
    "line {line}" : "行 {line}",
    "Filter log levels" : "ログレベルのフィルタ",
    "Time format" : "時間形式",
    "Live view" : "ライブビュー",
    "Download / Upload logs" : "Download / Upload logs",
    "Download logs" : "ログのダウンロード",
    "Show local log file" : "ローカルのログファイルを表示する",
    "Upload local log file to be displayed" : "表示するローカルログファイルをアップロードする",
    "Raw data" : "未加工データ",
    "Local time" : "ローカル時間",
    "UTC time" : "UTC時間",
    "Time format used for displaying the timestamp" : "タイムスタンプの表示に使用される時間形式",
    "(Local log files only support the \"raw\" time format)" : "(ローカルログファイルは「未加工」の時間形式のみサポート)",
    "Could not change date time format." : "日付と時刻のフォーマットを変更できませんでした。",
    "Polling is disabled because server is not configured to log to file" : "サーバーがファイルにログを記録するように設定されていないため、ポーリングが無効になっています。",
    "Polling (live view)" : "ポーリング (live view)",
    "Could not change live view setting." : "ライブビューの設定を変更できなかった。",
    "Filter logging levels" : "ログレベルのフィルター",
    "Could not set logging levels to show" : "表示するログレベルを設定できませんでした",
    "Application" : "アプリケーション",
    "Message" : "メッセージ",
    "Log entry actions" : "Log entry actions",
    "Loading older log entries" : "古いログエントリの読み込み中",
    "No older log entries available" : "古いログエントリーはありません",
    "Collapse row" : "行を折りたたむ",
    "Expand row" : "行を展開する",
    "Show details" : "詳細を見る",
    "Debug" : "デバッグ",
    "Info" : "情報",
    "Warning" : "警告",
    "Error" : "エラー",
    "Fatal" : " 致命的なエラー",
    "Could not fetch new log entries (server unavailable)" : "新しいログエントリを取得できませんでした（サーバーが使用できません）",
    "Could not fetch new entries" : "新しいエントリーを取得できませんでした",
    "Could not copy to clipboard, please copy manually:" : "クリップボードにコピーできませんでした。手動でコピーしてください：",
    "\tfrom {address} by {user} at {time}\n" : "\tfrom {address} by {user} at {time}\n",
    "Error parsing log" : "ログ解析失敗",
    "Caused by " : "原因：",
    "Copy" : "コピー",
    "Copy raw" : "そのままコピー",
    "Copy formatted" : "フォーマット済みのコピー",
    "No server logs" : "サーバーログがありません",
    "One or more entries are hidden by the log level filter" : "ログレベルでフィルタリングされている行があります",
    "Everything is working fine" : "問題ありません",
    "Load log file" : "ログファイルを読み込む",
    "Invalid log file" : "不正なログファイルです",
    "Log levels" : "ログレベル",
    "Log content" : "ログ情報",
    "Live update" : "ライブアップデート"
},
"nplurals=1; plural=0;");

==> nextcloud-26.0.10.tgz: nextcloud/apps/logreader/l10n/ja.js <==
OC.L10N.register(
    "logreader",
    {
    "Logging" : "ログ",
    "Log Reader" : "ログリーダー",
    "A log reader for Nextcloud" : "NextCloudのためのログリーダー",
    "Log reader for Nextcloud" : "NextCloudのためのログリーダー",
    "Log reader" : "ログリーダー",
    "Open log reader settings" : "ログリーダーの設定を開く",
    "Log reader settings" : "ログリーダーの設定",
    "Currently the log file {file} is shown" : "現在、ログファイル {file} が表示されています。",
    "Show server log" : "サーバーログを表示",
    "Live view is disabled" : "ライブビューは無効",
    "No log file" : "ログファイルがありません",
    "File-based logging must be enabled to access logs from the Web UI." : "Web UIからログにアクセスするには、ファイルベースのログを有効にする必要があります。",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "エラーと思われる場合は、 {config} の {setting} を確認し、Nextcloud管理マニュアルをご確認ください。",
    "Level" : "レベル",
    "App" : "アプリ",
    "No app in context" : "No app in context",
    "Time" : "時間",
    "Copy raw entry" : "原文のままコピーする",
    "Copy formatted entry" : "フォーマットされたエントリーをコピーする",
    "Hide exception details" : "例外の詳細を非表示にする",
    "View exception details" : "例外の詳細を表示する",
    "Raw log entry" : "原文のログエントリー",
    "Log entry successfully copied" : "ログが正常にコピーされました",
    "Search log entries" : "ログの検索",
    "Caused by {exception}" : "{exception} が原因",
    "Filter log levels" : "ログレベルのフィルタ",
    "Time format" : "時間形式",
    "Live view" : "ライブビュー",
    "Download logs" : "ログのダウンロード",
    "Show local log file" : "ローカルのログファイルを表示する",
    "Upload local log file to be displayed" : "表示するローカルログファイルをアップロードする",
    "Raw data" : "未加工データ",
    "Local time" : "ローカル時間",
    "UTC time" : "UTC時間",
    "Time format used for displaying the timestamp" : "タイムスタンプの表示に使用される時間形式",
    "(Local log files only support the \"raw\" time format)" : "(ローカルログファイルは「未加工」の時間形式のみサポート)",
    "Could not change date time format." : "日付と時刻のフォーマットを変更できませんでした。",
    "Polling is disabled because server is not configured to log to file" : "サーバーがファイルにログを記録するように設定されていないため、ポーリングが無効になっています。",
    "Polling (live view)" : "ポーリング (live view)",
    "Could not change live view setting." : "ライブビューの設定を変更できなかった。",
    "Filter logging levels" : "ログレベルのフィルター",
    "Could not set logging levels to show" : "表示するログレベルを設定できませんでした",
    "Application" : "アプリケーション",
    "Message" : "メッセージ",
    "Log entry actions" : "Log entry actions",
    "Loading older log entries" : "古いログエントリの読み込み中",
    "No older log entries available" : "古いログエントリーはありません",
    "Collapse row" : "行を折りたたむ",
    "Expand row" : "行を展開する",
    "Show details" : "詳細を見る",
    "Debug" : "デバッグ",
    "Info" : "情報",
    "Warning" : "警告",
    "Error" : "エラー",
    "Fatal" : " 致命的なエラー",
    "Could not fetch new log entries (server unavailable)" : "新しいログエントリを取得できませんでした（サーバーが使用できません）",
    "Could not fetch new entries" : "新しいエントリーを取得できませんでした",
    "Could not copy to clipboard, please copy manually:" : "クリップボードにコピーできませんでした。手動でコピーしてください：",
    "\tfrom {address} by {user} at {time}\n" : "\tfrom {address} by {user} at {time}\n",
    "Error parsing log" : "ログ解析失敗",
    "Caused by " : "原因：",
    "Copy" : "コピー",
    "Copy raw" : "そのままコピー",
    "Copy formatted" : "フォーマット済みのコピー",
    "No server logs" : "サーバーログがありません",
    "One or more entries are hidden by the log level filter" : "ログレベルでフィルタリングされている行があります",
    "Everything is working fine" : "問題ありません",
    "Load log file" : "ログファイルを読み込む",
    "Invalid log file" : "不正なログファイルです",
    "Log levels" : "ログレベル",
    "Log content" : "ログ情報",
    "Live update" : "ライブアップデート",
    "line {line}" : "行 {line}",
    "Download / Upload logs" : "Download / Upload logs"
},
"nplurals=1; plural=0;");
